---
title: Elle
description: A namespace for finite element libraries targeted at research into neural network architectures.
template: partials/pkg_index.html
...

# Elle Namespace

A namespace for finite element libraries targeted at research into neural network architectures.


<!--

---------------------------


[![Commits since latest release][gh-image]][gh-link]

[pypi-v-image]: https://img.shields.io/pypi/v/elle.svg
[pypi-v-link]: https://pypi.org/project/elle/

[travis-image]: https://api.travis-ci.org/claudioperez/elle.svg?branch=master
[travis-link]: https://travis-ci.org/claudioperez/elle

[gh-link]: https://github.com/claudioperez/elle/compare/v0.0.0...master
[gh-image]: https://img.shields.io/github/commits-since/claudioperez/elle/v0.0.0.svg
[![Documentation](https://img.shields.io/badge/documentation-blue)](https://www.claudioperez.xyz/pkgs/elle)

## Installation

`elle` is a namespace that contains several packages which can be installed independently


## Packages

```{rst}
.. rendre:: gallery
   :verbose:

```

-->
